@@ -22,4 +22,7 @@ class ApiStub(Stub):
         self._send('get-daily-companies', {})
 
     def get_all_companies(self):
-        self._send('get-all-companies', {})
\ No newline at end of file
+        self._send('get-all-companies', {})
+        
+    def live_prediction(self, content):
+        self._send('live-prediction', {})
\ No newline at end of file
